﻿using UnityEngine;

namespace GameTools
{
	public class GUILoginWindow
	{
		#region vars
		private string username="";
		private string windowName="";
		private string doneButtonText="";
		private bool userLoggedIn = false;
		private Rect overrideRect;
		private bool overrideSize= false;
		
		// this is an object that must be placed in the scene which will 
		// be our conduit to the PHP scripts
		private GameObject MonitoringObject = null;
		// the object to interact with online data
		public OnlineUserData onlineData = null;
		public bool UserLoggedIn
		{
			get {return userLoggedIn;}
		}

		#endregion
		public GUILoginWindow (string _windowName, string _doneButtonText, string _defaultUserName, GameObject _MonitoringObject,string Game, bool _overrideSize, Rect _overrideRect)
		{
			overrideSize = _overrideSize;
			overrideRect = _overrideRect;
			windowName = _windowName;
			doneButtonText = _doneButtonText;
			username = _defaultUserName;
			MonitoringObject = _MonitoringObject;
			if (MonitoringObject != null) {
				onlineData = (OnlineUserData) MonitoringObject.AddComponent(typeof(OnlineUserData));
				onlineData.GAME = Game;
				onlineData.MyLoginParent = this;
			}
			
		}
		
		public string GetUserName
		{
			get {return username;}
		}
		string ToTitleCase(string stringToConvert)
			
		{
			
			string firstChar= stringToConvert[0].ToString();
			
			return (stringToConvert.Length>0 ? firstChar.ToUpper()+stringToConvert.Substring(1) : stringToConvert);
			
			
			
		}
		public string GetUserName_ForDisplay
		{
			get {return ToTitleCase(username);}
		}

		
		bool userHasHitReturn = false;

		// Make the contents of the window (generalized this)
		private void LoginWindow (int windowID)
		{
			Rect toUse = new Rect (5, 20, 110, 75);
			if (overrideSize)
			{
				toUse = overrideRect;
			}


			GUILayout.BeginArea (toUse);
			GUI.SetNextControlName ("username");

			Event e = Event.current;
			if (e.keyCode == KeyCode.Return && Event.current.type == EventType.KeyDown)
				userHasHitReturn = true;
			else if (false == userHasHitReturn) {
				username = GUILayout.TextField (username, 15);
			}
		
			
			if (GUILayout.Button (doneButtonText) || userHasHitReturn)
			{
				username = ScreenShot.BuildSafeFilename (username).ToLower ();
				userLoggedIn = true;
			}
			
			GUI.FocusControl("username");
			GUILayout.EndArea();
			
		}
		/// <summary>
		/// Shows the login modal dialog
		/// </summary>
		public bool ShowLogin()
		{

			bool returnvalue = false;

			if ("" == windowName) {
				Debug.Log("Please Define a Window Name");
			}
			if ("" == doneButtonText) {
				Debug.Log("Define a done button");
				
			}
			int window_width = 120;
			int window_height = 75;
			if (overrideSize)
			{
				window_width = (int)overrideRect.width;
				window_height = (int)overrideRect.height;
			}

			if (false == UserLoggedIn) {
				
				
				GUIManager.Instance.DoPause();
				GUIManager.Instance.SystemPauseLockOn();
				
				Rect windowRect = GUIManager.WindowCenter(window_width,window_height);
				
				windowRect = GUI.ModalWindow (0, windowRect, LoginWindow, windowName);
				

			}
			else
			{
				GUIManager.Instance.SystemPauseLockOff();
				GUIManager.Instance.TogglePause ();
				returnvalue = true;
			}

			return returnvalue;
		}

	}
}

