﻿using System;
using UnityEngine;

/// <summary>
/// GUI manager.
/// 
/// Helper routines when building Unity interfaces.
/// </summary>
namespace GameTools
{
	public class GUIManager
	{

		protected static volatile GUIManager instance;
		protected static object syncRoot = new System.Object();
		public static GUIManager Instance
		{
			get
			{
				if (null == instance)
				{
					// only one instance is created and when needed
					lock (syncRoot)
					{
						if (null == instance)
						{
							
							instance = new GUIManager();
						}
					}
				}
				return (GUIManager)instance;
			}
		}
		public GUIManager ()
		{
		}



		#region pause
		private bool paused = false;
		private bool systempauselock = false;

		public void SystemPauseLockOn ()
		{
			systempauselock = true;
		}

		public void SystemPauseLockOff ()
		{
			systempauselock = false;
		}

		public bool IsPaused ()
		{
			return paused;
		}
	
		public void DoPause ()
		{
			if (systempauselock)
				return;
			paused = true;
			Pause.DoPause (true);
		}

		public void UnPause ()
		{
			if (systempauselock)
				return;
			Pause.DoPause (false);
			paused = false;
		}

		public void TogglePause ()
		{
			if (systempauselock)
				return;

			if (true == paused) {
				UnPause ();
			
			} else {
				DoPause ();
			
			}
		}
		public static Rect WindowCenter (int width, int height)
		{
			Rect defaultrec = new Rect ((Screen.width / 2) - 50, (Screen.height / 2) - 50, width, height);

			return defaultrec;
		}
		public static void ProgressBar(Rect loc, Texture _progressTexture, float percentage, string caption, Color barColor, Color textColor)
		{

			
			
			float length = loc.width * percentage;
			if (length > loc.width) length = loc.width; if (length <15) length = 15;
			GUI.BeginGroup( new Rect( loc.x, loc.y,length, loc.height ) );
			Color holder =GUI.color;
			GUI.color = barColor;
			GUI.DrawTexture(new  Rect( loc.x, loc.y, loc.width, loc.height ), _progressTexture ); // Note the 100 for the width
			
			GUI.EndGroup();
			GUI.color = textColor;

			caption =string.Format ("<size=20>{0}</size>",caption);
			GUIContent content = new GUIContent(caption);
			GUI.Label(new  Rect( loc.x, loc.y, loc.width, loc.height), content);
			
			GUI.color = holder;
		}
		/// <summary>
		/// Shows the billboard.
		/// 
		/// It is up to the billboard object (a TextMesh) to destroy itself)
		/// </summary>
		/// <param name='message'>
		/// Message.
		/// </param>
		/// <param name='Billboard>a TextMesh prefab</param>
		public static TextMesh ShowBillboard(string message, TextMesh Billboard)
		{TextMesh FloatingMessage=null;
			if (Billboard != null)
			{
				simplelog.Instance.Line("Level", simplelog.ProblemType.MESSAGE, "ShowBillboard");
				if (Camera.main != null)
				{

					Vector3 pos = Camera.main.ScreenToWorldPoint(new Vector2(Screen.width/2, Screen.height/2));
					
					FloatingMessage= (TextMesh)GameObject.Instantiate(Billboard, new Vector3(pos.x, pos.y,0), Quaternion.identity);



					FloatingMessage.transform.rotation = new Quaternion(0,180,0,0);
					FloatingMessage.text = message;
				}
				else
				{
					simplelog.Instance.Line("Level", simplelog.ProblemType.MESSAGE, "Camera was null");
				}
			}
			return FloatingMessage;
		}
		#endregion
	}

}